#ifndef ESFILES_H
#define ESFILES_H

#include <QObject>
#include <QStringList>
#include <QSet>
#include <QUrl>
#include <QMap>
#include <QProcess>

class QIODevice;

#include "datadownloader.h"

class ESFiles : public DataDownloader
{
    Q_OBJECT

public:
    ESFiles( QObject *parent );
    virtual ~ESFiles();
	virtual QUrl getUrl();
	void initSettings();
	virtual void setInput(DownloadInput d);
	virtual QString finishedDownload(QString channel, QIODevice *source);
	void sendRecordMsg(QStringList data);

signals:

public slots:

private slots:
	void sentRecordMsg(int exitCode, QProcess::ExitStatus exitStatus);

protected:

private:
	const char* HELPERPATH;
};

#endif // ESFILES_H
